mod database;
mod sheet;
mod sheet_dao;
mod sheet_validation;
mod ui;

use std::{path::PathBuf, process};

use clap::Parser;
use database::Database;
use env_logger::Env;
use log::error;
use relm4::RelmApp;

use crate::ui::app::{AppInitData, AppModel};

#[derive(Parser)]
#[command(author, version, about)]
struct Cli {
    directory: PathBuf,
}

#[tokio::main]
async fn main() {
    env_logger::Builder::from_env(Env::default().default_filter_or("debug")).init();
    let cli = Cli::parse();
    if !cli.directory.is_dir() {
        error!("Sheet folder path is no dir or does not exist");
        process::exit(1);
    }

    let database = Database::setup(cli.directory.join("database.sqlite"))
        .await
        .unwrap();

    let sheets = sheet_validation::load_and_validate_sheets(&database, &cli.directory).await;

    let app_init_data = AppInitData {
        sheets,
        database,
        directory: cli.directory,
    };
    let app = RelmApp::new("de.frajul.sheet-organizer");
    // Pass empty command line args to allow my own parsing
    app.with_args(Vec::new())
        .run_async::<AppModel>(app_init_data);
}
